//Copyright (c) 1998 The Open Group
//
//Permission to use, copy, modify, and distribute this software and its documentation for
//any purpose and without fee is hereby granted, provided that the above copyright notice
//appears in all copies and that both the copyright notice and this permission notice
//appear in supporting documentation, and that the name of ("TOG") or The Open Group not
//be used in advertising or publicity pertaining to distribution of the software without
//specific, written prior permission.
//
//THE OPEN GROUP DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
//IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT
//SHALL TOG BE LIABLE FOR ANY SPECIAL, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
//WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN ACTION OF CONTRACT,
//NEGLIGENCE, OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
//PERFORMANCE OF THIS SOFTWARE. 

package ORG.opengroup.axtp;
import java.beans.*;
import java.io.*;

/**
 * A bean which manages the retry delay.
 */
public class RetryDelay implements Serializable, Cloneable
{
	private int initialDelay=10;
	private int minInitialDelay=2;
	private int delayIncriment=1;
	private int minDelayIncriment=1;
	private int delayLimit=1000;
	private int minDelayLimit=100;

	private int currentDelay=initialDelay;

	public void setInitialDelay(int v)
	{
		if (v<minInitialDelay)
			initialDelay=minInitialDelay;
		else
			initialDelay=v;
		currentDelay=initialDelay;
	}

	public int getInitialDelay()
	{
		return initialDelay;
	}

	/**
	 * Throws an error if not called during DesignTime.
	 */
	public void setMinInitialDelay(int v)
	{
		if (!Beans.isDesignTime())
			throw new Error("not DesignTime");
		minInitialDelay=v;
	}

	public int getMinInitialDelay()
	{
		return minInitialDelay;
	}

	public void setDelayIncriment(int v)
	{
		if (v<minDelayIncriment)
			delayIncriment=minDelayIncriment;
		else
			delayIncriment=v;
	}

	public int getDelayIncriment()
	{
		return delayIncriment;
	}

	/**
	 * Throws an error if not called during DesignTime.
	 */
	public void setMinDelayIncriment(int v)
	{
		if (!Beans.isDesignTime())
			throw new Error("not DesignTime");
		minDelayIncriment=v;
	}

	public int getMinDelayIncriment()
	{
		return minDelayIncriment;
	}

	public void setDelayLimit(int v)
	{
		if (v<minDelayLimit)
			delayLimit=minDelayLimit;
		else
			delayLimit=v;
	}

	public int getDelayLimit()
	{
		return delayLimit;
	}

	/**
	 * Throws an error if not called during DesignTime.
	 */
	public void setMinDelayLimit(int v)
	{
		if (!Beans.isDesignTime())
			throw new Error("not DesignTime");
		minDelayLimit=v;
	}

	public int getMinDelayLimit()
	{
		return minDelayLimit;
	}

	public int getCurrentDelay()
	{
		return currentDelay;
	}

	public void resetDelay()
	{
		currentDelay=initialDelay;
	}

	public void incrimentDelay()
	{
		int t=currentDelay+delayIncriment;
		if (t>delayLimit)
			t=delayLimit;
		currentDelay=t;
	}

	public Object clone()
	{
		try
		{
			return super.clone();
		} catch (CloneNotSupportedException e)
		{
			return null;
		}
	}
}
