//Copyright (c) 1997 The Open Group
//
//Permission to use, copy, modify, and distribute this software and its documentation for
//any purpose and without fee is hereby granted, provided that the above copyright notice
//appears in all copies and that both the copyright notice and this permission notice
//appear in supporting documentation, and that the name of ("TOG") or The Open Group not
//be used in advertising or publicity pertaining to distribution of the software without
//specific, written prior permission.
//
//THE OPEN GROUP DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
//IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT
//SHALL TOG BE LIABLE FOR ANY SPECIAL, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
//WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN ACTION OF CONTRACT,
//NEGLIGENCE, OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
//PERFORMANCE OF THIS SOFTWARE. 

package ORG.opengroup.jar;
import ORG.opengroup.misc.*;
import java.io.*;
import java.util.zip.*;
import java.util.*;

/**
 * Adds file operations to Bucket
 */
public class JarFile extends Bucket
{
	private String fileName=null;

	/**
	 * Creates a Bucket with no content.
	 */
	public JarFile()
	{
		super();
	}

	/**
	 * Creates a bucket with the content of a jar file.
	 * @param pfileName Name of jar file.
	 * @exception	IOException		May be thrown when
	 *						reading from the jar file.
	 *
	 * @exception	ZipException 	May be thrown when
	 *						processing the contents of the
	 *						jar file.
	 */
	public JarFile(String pfileName)
		throws IOException, ZipException
	{
		super(new FileInputStream(pfileName));
		fileName=pfileName;
	}

	/**
	 * Write the bucket to a jar file.
	 *
	 * @param pfileName Name of jar file.
	 *
	 * @exception	IOException		May be thrown when
	 *						writting to the jar file.
	 *
	 * @exception	ZipException 	May be thrown when
	 *						processing the contents of the
	 *						jar file.
	 */
	public void saveAs(String pfileName)
		throws IOException, ZipException
	{
		fileName=pfileName;
		jar(new FileOutputStream(pfileName));
	}

	/**
	 * Update the jar file.
	 *
	 * @exception	IOException		May be thrown when
	 *						writting to the jar file.
	 *
	 * @exception	ZipException 	May be thrown when
	 *						processing the contents of the
	 *						jar file.
	 */
	public void save()
		throws IOException, ZipException
	{
		saveAs(fileName);
	}

	/**
	 * Put a file in the bucket.
	 * @param pfileName Name of the file to be put in the bucket.
	 * @exception IOException May be thrown when reading the file.
	 */
	public void putFile(String pfileName)
		throws IOException
	{
		putFile(pfileName,pfileName);
	}

	/**
	 * Put a file in the bucket.
	 * @param pfileName Name of the file to be read.
	 * @param as Name of the file added to the bucket.
	 * @exception IOException May be thrown when reading the file.
	 */
	public void putFile(String pfileName, String as)
		throws IOException
	{
		File file=new File(pfileName);
		long modified=file.lastModified();
		InputStream is=new FileInputStream(file);
		String name=as.replace('\\','/');
		byte value[]=Reads.read(is);
		put(name,value,modified);
		if (!name.equals(MANIFEST_NAME))
			manifest.force(name).addHash(value);
	}

	/**
	 * Creates a clone of this jarfile instance and 
	 * passes it back
	 */
	public synchronized Object clone()
	{
		JarFile theClone = new JarFile();
		theClone.pairs=(Vector)pairs.clone();
		theClone.manifest=(Manifest)manifest.clone();
		theClone.fileName = fileName;
		return theClone;
	}
}  
